#' ---
#' title: |
#'   医薬品開発のための統計解析 第２部4章１節 \
#'   共分散分析の目的 \
#'   Green2-4-1.R
#' author: "Masahiko Katase"
#' date: "2021/6/6"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(ellipse)   # ellipse

df <- read_excel("Green2-4.xlsx", sheet = "4-kyobunsan1")
df <- data.frame(df)
df$group <- as.factor(df$group)

#'# 表示 4.1.1、年収の比較調査の結果（p.133）
df

by(df$incom, df$group, summary)
by(df$age, df$group, summary)

plot.new()　　　　　　　　　 # グラフ消去　
par(mfcol = c(1, 2))    　　 # プロットエリアを１行２列に分割　
par(mar = c(4, 4, 1, 1)) 　　# 下左上右の余白間隔を設定
g <- 2:4                     # 会社を 2,3,4 の色と形で区別 

boxplot(income ~ group, data = df, ylim = c(500, 1000), col = g)

#'# 表示4.1.2 年齢と年収の関係（p.134）
plot(x = df$age, y = df$income, type = "p", 
     col = g[unclass(df$group)], pch = g[unclass(df$group)], 
     xlim = c(25, 50), ylim = c(500, 1000),
     xlab = "age", ylab = "income")

df1 <- subset(df, group == "A1", select = c(age, income))
df2 <- subset(df, group == "A2", select = c(age, income))
df3 <- subset(df, group == "A3", select = c(age, income))
polygon(ellipse(cov(df1), centre = colMeans(df1), level = 0.50), 
        lty = 1, lwd = 1, border = 2)
polygon(ellipse(cov(df2), centre = colMeans(df2), level = 0.50), 
        lty = 1, lwd = 1, border = 3)
polygon(ellipse(cov(df3), centre = colMeans(df3), level = 0.50), 
        lty = 1, lwd = 1, border = 4)
