#' ---
#' title: |
#'   医薬品開発のための統計解析 第２部4章2節 \
#'   共分散分析　解析手順 \
#'   Green2-4-2a.R
#' author: "Masahiko Katase"
#' date: "2021/6/29"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(emmeans)   # emmeans

df <- read_excel("Green2-4.xlsx", sheet = "4-kyobunsan1")
df <- data.frame(df)
df$group <- as.factor(df$group)

#'# 表示 4.2.1 年収の分散分析表と平均値の差の比較
by(df$income, df$group, mean)

lm_out <- lm(income ~ group, data = df)
anova(lm_out)

pairwise.t.test(df$income, df$group, p.adjust.method = "none")
emmeans_out1 <- emmeans(lm_out, specs = "group")
emmeans_out1
pairs(emmeans_out1, adjust = "none")

#'# 表示4.2.2 年齢と年収の関係
df1 <- subset(df, group == "A1", select = c(age, income))
df2 <- subset(df, group == "A2", select = c(age, income))
df3 <- subset(df, group == "A3", select = c(age, income))

lm_out1 <- lm(income ~ age, data = df1)
lm_out2 <- lm(income ~ age, data = df2)
lm_out3 <- lm(income ~ age, data = df3)

g <- 2:4

plot(x = df$age, y = df$income,
     type = "p", col = g[df$group], pch = g[df$group], 
     xlim = c(25, 50), ylim = c(500, 1000),
     xlab = "age", ylab = "income")
abline(lm_out1, col = 2)
abline(lm_out2, col = 3)
abline(lm_out3, col = 4)
points(mean(df1$age), mean(df1$income), pch = 3, cex = 3, col = 2)
points(mean(df2$age), mean(df2$income), pch = 3, cex = 3, col = 3)
points(mean(df3$age), mean(df3$income), pch = 3, cex = 3, col = 4)

f1 <- coef(lm_out1)
f2 <- coef(lm_out2)
f3 <- coef(lm_out3)
rbind(A1 = f1, A2 = f2, A3 = f3)
