#' ---
#' title: |
#'   医薬品開発のための統計解析 第２部4章2節 \
#'   共分散分析　解析手順 \
#'   Green2-4-2c.R
#' author: "Masahiko Katase"
#' date: "2021/7/1"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(car)       # Anova
library(emmeans)   # emmeans
library(multcomp)  # cld

df <- read_excel("Green2-4.xlsx", sheet = "4-kyobunsan1")
df <- data.frame(df)
df$group <- as.factor(df$group)

#'# 表示 4.2.8 傾きの等しい直線のあてはめ結果
lm_out <- lm(income ~ group + age, data = df, 
             contrasts = list(group = "contr.sum"))
summary(lm_out)
Anova(lm_out, type = 3)

coef_out <- coef(lm_out)  # 係数と切片を取り出す
est_a    <- coef_out[1]
est_g1   <- coef_out[2]
est_g2   <- coef_out[3]
est_g3   <- -(est_g1 + est_g2)  
est_b    <- coef_out[4] 
fn1 <- function(x) est_a + est_g1 + est_b * x
fn2 <- function(x) est_a + est_g2 + est_b * x
fn3 <- function(x) est_a + est_g3 + est_b * x

g <- 2:4
par(mfrow = c(1,1))
par(mar = c(4, 4, 1, 1))
plot(x = df$age, y = df$income, type = "p",
     pch = g[unclass(df$group)], col = g[unclass(df$group)],
     xlim = c(25, 50), ylim = c(550, 950))
curve(fn1, xlim = c(25, 50), ylim = c(550, 950), col = 2, add = TRUE)
curve(fn2, xlim = c(25, 50), ylim = c(550, 950), col = 3, add = TRUE)
curve(fn3, xlim = c(25, 50), ylim = c(550, 950), col = 4, add = TRUE)

#'# 表示4.2.9 A2-A1、A3-A1 の推定と検定
# ペアごとのStudentのt検定（多重性を考慮しない比較）
emmeans_out1 <- emmeans(lm_out, specs = "group")
emmeans_out1
pairs(emmeans_out1, adjust = "none")
cld(emmeans_out1, adjust = "none", 
    sort = TRUE, reversed = TRUE, Letters = letters)
plot(emmeans_out1, comparisons = TRUE)

# ペアごとのTukeyの多重比較（多重性を考慮した比較）
emmeans_out2 <- emmeans(lm_out, specs = "group")
pairs(emmeans_out2, adjust = "tukey")
cld(emmeans_out2, adjust = "tukey",
    sort = TRUE, reversed = TRUE, Letters = letters)
plot(emmeans_out2, comparisons = TRUE)

# 対照群とのDunnettx検定（多重性を考慮した比較）
emmeans(lm_out, specs = trt.vs.ctrl ~ group, ref = 1)

#'# 標葉4.2.11 傾きの違いの検定
center = mean(df$age)   # 中心化のため平均を計算
lm_out1 <- lm(income ~ group * I(age - center), data = df, 
              contrasts = list(group = "contr.sum"))
Anova(lm_out1, type = 3)
