#' ---
#' title: |
#'   医薬品開発のための統計解析 第２部4章3節 \
#'   医薬品開発における共分散分析の例 \
#'   Green2-4-3c.R
#' author: "Masahiko Katase"
#' date: "2021/7/5"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(car)       # Anova

df <- read_excel("Green2-4.xlsx", sheet = "4-kyobunsan3")
df <- data.frame(df)
df$group <- as.factor(df$group)

#'# 表示4.3.9 降圧剤A1、A2の効果の比較データ（p.158）
df <- transform(df, delta1 = (df$y - df$x))
df1 <- subset(df, subset = group == "A1", select = -group)
df2 <- subset(df, subset = group == "A2", select = -group)
df11 <- rbind(df1, colMeans(df1))
df21 <- rbind(df2, colMeans(df2))
rownames(df11) <- c(1:10, "means")
rownames(df21) <- c(1:10, "means")
df11
df21

#'# 表示4.3.10 個体ごとの血圧の変化グラフ（p.158）
par(mfrow = c(1,2))
par(mar = c(4, 4, 1, 1))
xrange <- 0:2
df11 <- cbind(df11, id = 1:11)  # 11番目は平均値
df21 <- cbind(df21, id = 1:11)

plot(NA, type = "n", xlim = c(0, 2), ylim = c(80, 200), xaxt = "n",
     xlab = "time", ylab = "obs")
axis(side = 1, at = xrange, labels = c("initial-z", "before-x", "after-y"))
text(x = 0.3, y = 190, labels = "A1" )
for (i in 1:10) lines(xrange, df11[i, 1:3], col = df11$id[i], lty = df11$id[i])
lines(xrange, df11[11, 1:3], col = 1, lty = 1, lwd = 3)

plot(NA, type = "n", xlim = c(0, 2), ylim = c(80, 200), xaxt = "n",
     xlab = "time", ylab = "obs")
axis(side = 1, at = xrange, labels = c("initial", "before", "after"))
text(x = 0.3, y = 190, labels = "A2" )
for (i in 1:10) lines(xrange, df21[i, 1:3], col = df21$id[i], lty = df21$id[i])
lines(xrange, df21[11, 1:3], col = 1, lty = 1, lwd = 3)

#'# 表示4.3.11 血圧の変化量(d)の違いの検定（p.159）
t.test(y ~ group, data = df, paried = FALSE, var.equal = TRUE)

t.test(delta1 ~ group, data = df, paried = FALSE, var.equal = TRUE)

#'# 表示4.3.12 投与前値xを横軸とするyとd=y-xの散布図（p.159）
g <- case_when(df$group == "A1" ~ 1,
               df$group == "A2" ~ 2)
df <- cbind(df, g = g)
par(mfrow = c(1,2))
par(mar = c(4, 4, 1, 1))
plot(x = df$x, y = df$y, type = "p", col = df$g, pch = df$g, 
     xlim = c(120, 200), ylim = c(100, 190), xlab = "x", ylab = "y")
abline(lm(y ~ x, data = df1), col = 1)
abline(lm(y ~ x, data = df2), col = 2)
plot(x = df$x, y = df$delta1, type = "p", col = df$g, pch = df$g, 
     xlim = c(120, 200), ylim = c(-40, 0), xlab = "x", ylab = "delta1(y-x)")
abline(lm(delta1 ~ x, data = df1), col = 1)
abline(lm(delta1 ~ x, data = df2), col = 2)

#'# 表示4.3.14 JMP による共分散分析の結果（p.161）
lm_out1 <- lm(delta1 ~ group + x, data = df, 
              contrasts = list(group = "contr.sum"))
summary(lm_out1)
Anova(lm_out1, type = 3)

est_a  <- coef(lm_out1)[1]
est_g1 <- coef(lm_out1)[2]
est_g2 <- -coef(lm_out1)[2]
est_b  <- coef(lm_out1)[3]

fn1 <- function(x) est_a + est_g1 + est_b * x
fn2 <- function(x) est_a + est_g2 + est_b * x

# グラフ
plot.new()　　　　　　　　　　
par(mfcol = c(1, 1))    　　 # プロットエリアを１行２列に分割　
par(mar = c(4, 4, 1, 1)) 　　# 下左上右の余白間隔を設定
plot(x = df$x, y = df$delta1, type = "p", col = df$g, pch = df$g, 
     xlim = c(120, 200), ylim = c(-40, 0), 
     xlab = "x", ylab = "delta1(y-x)")
curve(fn1,  xlim = c(120, 200), ylim = c(-40, 0), col = 1, add = TRUE)
curve(fn2,  xlim = c(120, 200), ylim = c(-40, 0), col = 2, add = TRUE)

#'# 表示4.3.15 横軸をx-zとする散布図（p.162）
delta2  <- df$x - df$z 
df <- cbind(df, delta2)
df12 <- subset(df, subset = group == "A1")
df22 <- subset(df, subset = group == "A2")
lm_out12 <- lm(delta1 ~ delta2 + 0, data = df12)
lm_out22 <- lm(delta1 ~ delta2 + 0, data = df22)
coef_out <- rbind(coef(lm_out12), coef(lm_out22))
rownames(coef_out) <- c("A1", "A2")
coef_out

plot.new()
par(mfrow = c(1,1))
par(mar = c(4, 4, 1, 1))
plot(x = df$delta2, y = df$delta1, type = "p", col = df$g, pch = df$g, 
     xlim = c(0, 60), ylim = c(-40, 0), 
     xlab = "detla2(x-z)", ylab = "delta1(y-x)")
abline(lm_out12, col = 1)
abline(lm_out22, col = 2)

#'、表示4.3.16（p.163）、表示4.3.17（p.164）JMP による別のモデルの結果
# ダミー変数１による解
dA2 <- c(rep(0, 10), rep(1, 10))
delta2dA2 = delta2 * dA2
df31 <- cbind(df, dA2, delta2dA2)
lm_out31 <- lm(delta1 ~ delta2 + delta2dA2 + 0, data = df31)
summary(lm_out31)
Anova(lm_out31, type = 3)

# ダミー変数２による解
DA1 <- c(rep(1, 10), rep(-1, 10))
delta2DA1 = delta2 * DA1
df32 <- cbind(df, DA1, delta2DA1)
lm_out32 <- lm(delta1 ~ delta2 + delta2DA1 + 0, data = df32)
summary(lm_out32)
Anova(lm_out32, type = 3)
